-- GridTest.lua should do nothing more than allow placing a Brain, i.e. giving the player something to control in the Scene. 
-- This is meant to be the absolute minimum to place a Scene on the Scenario Map for the GridTest Activity and put an Actor in it.

-----------------------------------------------------------------------------------------
-- Start Activity
-----------------------------------------------------------------------------------------
function GridTest:StartActivity()
   	print("START! -- GridTest:StartActivity()!");
	for player = 0, self.PlayerCount - 1 do
	-- Check if we already have a brain assigned
		if not self:GetPlayerBrain(player) then
			local foundBrain = MovableMan:GetUnassignedBrain(self:GetTeamOfPlayer(player));
			-- If we can't find an unassigned brain in the scene to give each player, then force to go into editing mode to place one
			if not foundBrain then
				self.ActivityState = Activity.EDITING;
				AudioMan:ClearMusicQueue();
			else
				-- Set the found brain to be the selected actor at start
				self:SetPlayerBrain(foundBrain, player);
				self:SwitchToActor(foundBrain, player, self:GetTeamOfPlayer(player));
				self:SetLandingZone(self:GetPlayerBrain(player).Pos, player);
				-- Set the observation target to the brain, so that if/when it dies, the view flies to it in observation mode
				self:SetObservationTarget(self:GetPlayerBrain(player).Pos, player)
			end
		end
	end
	self.LZ = SceneMan.Scene:GetArea("GridTest Area");
	self.EnemyLZ = SceneMan.Scene:GetArea("GridTest Area");

end

-----------------------------------------------------------------------------------------
-- Pause Activity
-----------------------------------------------------------------------------------------
function GridTest:PauseActivity(pause)
    print("PAUSE! -- GridTest:PauseActivity()!");
end

-----------------------------------------------------------------------------------------
-- End Activity
-----------------------------------------------------------------------------------------
function GridTest:EndActivity()
    print("END! -- GridTest:EndActivity()!");
end

-----------------------------------------------------------------------------------------
-- Update Activity
-----------------------------------------------------------------------------------------
function GridTest:UpdateActivity()
	self:ClearObjectivePoints();

	if not (self.ActivityState == Activity.OVER) then
		-- Iterate through all human players
		for player = 0, self.PlayerCount - 1 do
			-- The current player's team
			local team = self:GetTeamOfPlayer(player);
	
			-- Make sure the game is not already ending
			-- Check if any player's brain is dead
			local brain = self:GetPlayerBrain(player);
			if not brain or not MovableMan:IsActor(brain) or not brain:HasObjectInGroup("Brains") then
				self:SetPlayerBrain(nil, player);
				-- Try to find a new unasigned brain this player can use instead, or if his old brain entered a craft
				local newBrain = MovableMan:GetUnassignedBrain(team);
				-- Found new brain actor, assign it and keep on truckin'
				if newBrain and self.braindead[player] == false then
					self:SetPlayerBrain(newBrain, player);
					self.AssignedBrains[player] = newBrain;
					self:SwitchToActor(newBrain, player, team);
				else
					FrameMan:SetScreenText("Your brain has been destroyed!", player, 333, -1, false);
					self.braindead[player] = true;
					
					-- Now see if all brains of self player's team are dead, and if so, end the game
					--if not MovableMan:GetClosestBrainActor(team) then
						self.WinnerTeam = self:OtherTeam(team);
						ActivityMan:EndActivity();
					--end
				end
			else
				-- Update the observation target to the brain, so that if/when it dies, the view flies to it in observation mode
				self:SetObservationTarget(brain.Pos, player)
			end -- 
		end --for
	end
end
--]]